@@ -1,6 +1,6 @@
 package LWP;
 
-our $VERSION = "6.15_004";
+$VERSION = "6.01";
 sub Version { $VERSION; }
 
 require 5.008;
@@ -10,8 +10,6 @@ require LWP::UserAgent;  # this should load everything you need
 
 __END__
 
-=encoding utf-8
-
 =head1 NAME
 
 LWP - The World-Wide Web library for Perl
@@ -101,11 +99,11 @@ The libwww-perl library is based on HTTP style communication. This
 section tries to describe what that means.
 
 Let us start with this quote from the HTTP specification document
-<URL:http://www.w3.org/Protocols/>:
+<URL:http://www.w3.org/pub/WWW/Protocols/>:
 
 =over 3
 
-=item *
+=item
 
 The HTTP protocol is based on a request/response paradigm. A client
 establishes a connection with a server and sends a request to the
@@ -154,25 +152,25 @@ The main attributes of the request objects are:
 
 =item *
 
-B<method> is a short string that tells what kind of
+The B<method> is a short string that tells what kind of
 request this is.  The most common methods are B<GET>, B<PUT>,
 B<POST> and B<HEAD>.
 
 =item *
 
-B<uri> is a string denoting the protocol, server and
+The B<uri> is a string denoting the protocol, server and
 the name of the "document" we want to access.  The B<uri> might
 also encode various other parameters.
 
 =item *
 
-B<headers> contains additional information about the
+The B<headers> contain additional information about the
 request and can also used to describe the content.  The headers
 are a set of keyword/value pairs.
 
 =item *
 
-B<content> is an arbitrary amount of data.
+The B<content> is an arbitrary amount of data.
 
 =back
 
@@ -185,22 +183,22 @@ The main attributes of objects of this class are:
 
 =item *
 
-B<code> is a numerical value that indicates the overall
+The B<code> is a numerical value that indicates the overall
 outcome of the request.
 
 =item *
 
-B<message> is a short, human readable string that
+The B<message> is a short, human readable string that
 corresponds to the I<code>.
 
 =item *
 
-B<headers> contains additional information about the
+The B<headers> contain additional information about the
 response and describe the content.
 
 =item *
 
-B<content> is an arbitrary amount of data.
+The B<content> is an arbitrary amount of data.
 
 =back
 
@@ -253,34 +251,34 @@ application.
 
 =item *
 
-B<timeout> specifies how much time we give remote servers to
+The B<timeout> specifies how much time we give remote servers to
 respond before the library disconnects and creates an
 internal I<timeout> response.
 
 =item *
 
-B<agent> specifies the name that your application uses when it
+The B<agent> specifies the name that your application should use when it
 presents itself on the network.
 
 =item *
 
-B<from> can be set to the e-mail address of the person
+The B<from> attribute can be set to the e-mail address of the person
 responsible for running the application.  If this is set, then the
 address will be sent to the servers with every request.
 
 =item *
 
-B<parse_head> specifies whether we should initialize response
+The B<parse_head> specifies whether we should initialize response
 headers from the E<lt>head> section of HTML documents.
 
 =item *
 
-B<proxy> and B<no_proxy> specify if and when to go through
-a proxy server. <URL:http://www.w3.org/History/1994/WWW/Proxies/>
+The B<proxy> and B<no_proxy> attributes specify if and when to go through
+a proxy server. <URL:http://www.w3.org/pub/WWW/Proxies/>
 
 =item *
 
-B<credentials> provides a way to set up user names and
+The B<credentials> provide a way to set up user names and
 passwords needed to access certain services.
 
 =back
@@ -497,7 +495,7 @@ Example:
 
 =head2 CPAN Requests
 
-URLs with scheme C<cpan:> are redirected to a suitable CPAN
+URLs with scheme C<cpan:> are redirected to the a suitable CPAN
 mirror.  If you have your own local mirror of CPAN you might tell LWP
 to use it for C<cpan:> URLs by an assignment like this:
 
@@ -584,12 +582,6 @@ These environment variables can be set to enable communication through
 a proxy server.  See the description of the C<env_proxy> method in
 L<LWP::UserAgent>.
 
-=item PERL_LWP_ENV_PROXY
-
-If set to a TRUE value, then the C<LWP::UserAgent> will by default call
-C<env_proxy> during initialization.  This makes LWP honor the proxy variables
-described above.
-
 =item PERL_LWP_SSL_VERIFY_HOSTNAME
 
 The default C<verify_hostname> setting for C<LWP::UserAgent>.  If
@@ -604,6 +596,13 @@ The file and/or directory
 where the trusted Certificate Authority certificates
 is located.  See L<LWP::UserAgent> for details.
 
+=item PERL_LWP_USE_HTTP_10
+
+Enable the old HTTP/1.0 protocol driver instead of the new HTTP/1.1
+driver.  You might want to set this to a TRUE value if you discover
+that your old LWP applications fails after you installed LWP-5.60 or
+better.
+
 =item PERL_HTTP_URI_CLASS
 
 Used to decide what URI objects to instantiate.  The default is C<URI>.
@@ -632,7 +631,7 @@ Markus B Krüger, Markus Laker, Martijn Koster, Martin Thurn, Matthew
 Eldridge, Matthew.van.Eerde, Matt Sergeant, Michael A. Chase, Michael
 Quaranta, Michael Thompson, Mike Schilli, Moshe Kaminsky, Nathan
 Torkington, Nicolai Langfeldt, Norton Allen, Olly Betts, Paul
-J. Schinder, peterm, Philip Guenther, Daniel Buenzli, Pon Hwa Lin,
+J. Schinder, peterm, Philip GuentherDaniel Buenzli, Pon Hwa Lin,
 Radoslaw Zielinski, Radu Greab, Randal L. Schwartz, Richard Chen,
 Robin Barker, Roy Fielding, Sander van Zoest, Sean M. Burke,
 shildreth, Slaven Rezic, Steve A Fink, Steve Hay, Steven Butler,
@@ -661,7 +660,7 @@ modify it under the same terms as Perl itself.
 The latest version of this library is likely to be available from CPAN
 as well as:
 
-  http://github.com/libwww-perl/libwww-perl
+  http://github.com/gisle/libwww-perl
 
 The best place to discuss this code is on the <libwww@perl.org>
 mailing list.
